==> apache-skywalking-rover-0.5.0-src.tgz: apache-skywalking-rover-0.5.0/pkg/tools/host/network.go <==
// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package host

import (
	"net"

	"github.com/apache/skywalking-rover/pkg/logger"
)

var interfaces map[int]*net.Interface
var log = logger.GetLogger("tools", "host")

func init() {
	if err := refreshInterfaces(); err != nil {
		panic(err)
	}
}

func NetworkName(ifindex int) string {
	i := interfaces[ifindex]
	if i != nil {
		return i.Name
	}
	if e := refreshInterfaces(); e != nil {
		log.Warnf("error to refresh interfaces: %v", e)
		return ""
	}
	i = interfaces[ifindex]
	if i != nil {
		return i.Name
	}
	return ""
}

func refreshInterfaces() error {
	results, err := net.Interfaces()
	if err != nil {
		return err
	}
	tmp := make(map[int]*net.Interface)
	for _, interf := range results {
		tmp[interf.Index] = &interf
	}
	interfaces = tmp
	return nil
}

==> apache-skywalking-rover-0.7.0-src.tgz: apache-skywalking-rover-0.7.0/pkg/tools/host/network.go <==
// Licensed to Apache Software Foundation (ASF) under one or more contributor
// license agreements. See the NOTICE file distributed with
// this work for additional information regarding copyright
// ownership. Apache Software Foundation (ASF) licenses this file to you under
// the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.

package host

import (
	"net"

	"github.com/apache/skywalking-rover/pkg/logger"
)

var interfaces map[int]*net.Interface
var log = logger.GetLogger("tools", "host")

func init() {
	if err := refreshInterfaces(); err != nil {
		panic(err)
	}
}

func NetworkName(ifindex int) string {
	i := interfaces[ifindex]
	if i != nil {
		return i.Name
	}
	if e := refreshInterfaces(); e != nil {
		log.Warnf("error to refresh interfaces: %v", e)
		return ""
	}
	i = interfaces[ifindex]
	if i != nil {
		return i.Name
	}
	return ""
}

func AllNetworkInterfaces() map[int]*net.Interface {
	return interfaces
}

func refreshInterfaces() error {
	results, err := net.Interfaces()
	if err != nil {
		return err
	}
	tmp := make(map[int]*net.Interface)
	for inx, interf := range results {
		tmp[interf.Index] = &results[inx]
	}
	interfaces = tmp
	return nil
}
